@@ -182,6 +182,9 @@
 #define HAVE_U_INT32_T 1
 #define HAVE_STRUCT_TIMESPEC
 
+/* Support for tagging symbols with __attribute__((visibility("hidden"))) */
+#define HAVE_VISIBILITY_HIDDEN 1
+
 /* Code tests*/
 #define STACK_DIRECTION -1
 #define TIME_WITH_SYS_TIME 1
@@ -195,6 +198,7 @@
 #define HAVE_BUILTIN_EXPECT 1
 #define HAVE_BUILTIN_STPCPY 1
 #define HAVE_GCC_ATOMIC_BUILTINS 1
+#define HAVE_GCC_SYNC_BUILTINS 1
 /* #undef HAVE_VALGRIND */
 
 /* IPV6 */
@@ -251,7 +255,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.13-6/plugin/scalability_metrics/tests;/build/percona-server/src/percona-server-5.7.13-6/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.13-6/plugin/query_response_time/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.14-7/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.14-7/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.14-7/plugin/scalability_metrics/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
@@ -272,6 +276,7 @@
 /* #undef HAVE_NCURSES_H */
 #define USE_LIBEDIT_INTERFACE 1
 #define HAVE_HIST_ENTRY 1
+/* #undef USE_NEW_EDITLINE_INTERFACE */
 #define USE_NEW_READLINE_INTERFACE 1
 #define HAVE_READLINE_HISTORY_H 1
 
@@ -386,15 +391,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 13
-#define MYSQL_VERSION_EXTRA "-6"
+#define MYSQL_VERSION_PATCH 14
+#define MYSQL_VERSION_EXTRA "-7"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.13-6"
+#define PACKAGE_STRING "MySQL Server 5.7.14-7"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.13-6"
-#define VERSION "5.7.13-6"
+#define PACKAGE_VERSION "5.7.14-7"
+#define VERSION "5.7.14-7"
 #define PROTOCOL_VERSION 10
 
 /*
